==> org.opennms.features.springframework-security-1.10.6-sources.jar: org/opennms/web/springframework/security/UpperCaseMd5PasswordEncoder.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2010-2012 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2012 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.web.springframework.security;

import org.springframework.security.providers.encoding.Md5PasswordEncoder;

/**
 * <p>UpperCaseMd5PasswordEncoder class.</p>
 */
public class UpperCaseMd5PasswordEncoder extends Md5PasswordEncoder {
    /** {@inheritDoc} */
    public String encodePassword(String rawPass, Object salt) {
    	// This is almost too easy -- I'm not complaining!!
        return super.encodePassword(rawPass, salt).toUpperCase();
    }
}

==> org.opennms.features.springframework-security-1.12.3-sources.jar: org/opennms/web/springframework/security/UpperCaseMd5PasswordEncoder.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2010-2012 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2012 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.web.springframework.security;

import org.springframework.security.authentication.encoding.Md5PasswordEncoder;

/**
 * <p>UpperCaseMd5PasswordEncoder class.</p>
 */
public class UpperCaseMd5PasswordEncoder extends Md5PasswordEncoder {
    /** {@inheritDoc} */
    public String encodePassword(String rawPass, Object salt) {
    	// This is almost too easy -- I'm not complaining!!
        return super.encodePassword(rawPass, salt).toUpperCase();
    }
}
